==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/error.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td valign="top" width="180">
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td class="txt_title">
						<?php echo $lang['section_menu'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php
						if (isset($homepage)) {
						?>
						<a href="<?php echo $homepage;?>" class="txt_sub_menu"><?php echo $lang['href_404_my_home'];?></a><br />
						<?php
						}
						?>

						<a href="index.php" class="txt_sub_menu"><?php echo $lang['href_404_home'];?></a><br />
						<a href="http://www.barnraiser.org/" class="txt_sub_menu"><?php echo $lang['href_404_barnraiser'];?></a><br />


						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

						<?php
						include $templatePath . "logo.inc.tpl.php";
						?>
					</td>
				</tr>
			</table>
		</td>

		<td width="20">&nbsp;<br /></td>

		<td valign="top" width="570">
			<table width="100%" border="0" cellspacing="0" cellpadding="4">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_error'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top">
						<?php echo $lang['txt_404_help'];?><br />
					</td>
				</tr>
			</table>
		</td>
	</tr>
</table>

==> aroundme_0_4_3.zip: aroundme_0_4_3/www/aroundme_0_4_3/template/am_default/error.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td valign="top" width="180">
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td class="txt_title">
						<?php echo $lang['section_menu'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php
						if (isset($homepage)) {
						?>
						<a href="<?php echo $homepage;?>" class="txt_sub_menu"><?php echo $lang['href_404_my_home'];?></a><br />
						<?php
						}
						?>

						<a href="index.php" class="txt_sub_menu"><?php echo $lang['href_404_home'];?></a><br />
						<a href="http://www.barnraiser.org/" class="txt_sub_menu"><?php echo $lang['href_404_barnraiser'];?></a><br />


						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

						<?php
						include $templatePath . "logo.inc.tpl.php";
						?>
					</td>
				</tr>
			</table>
		</td>

		<td width="20">&nbsp;<br /></td>

		<td valign="top" width="570">
			<table width="100%" border="0" cellspacing="0" cellpadding="4" class="table_stnd">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_error'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top">
						<?php echo $lang['txt_404_help'];?><br />
					</td>
				</tr>
			</table>
		</td>
	</tr>
</table>
